# i-need-an-image
Download only one image from web

确保可以从互联网上获取一张符合条件图片。可以指定图片的以下特征：
+ 关键词或一句话里的某个关键词
+ 图片的版式：横板、竖版、方形

我的关注点是尽可能地提高获取图片的成功率，可以通过不同细粒度的重试来达到这一目标：
1. 请求图片实际地址失败时进行重试。
2. 对同一搜索页面的不同图片进行请求尝试。
3. 尝试不同的来源网站（必应、百度、谷歌）。

架构愿景：
1. 希望可以像`Scrapy`的流水线一样，不同来源的下载器可随意插拔和扩展。
2. 入口点只有一个`give_me()`函数。
